module POEditor
  class Configuration
    # @return [String] POEditor API key
    # @see https://poeditor.com/account/api POEditor API Access
    attr_accessor :api_key

    # @return [String] POEditor project ID
    attr_accessor :project_id

    # @return [String] Export file type (po, apple_strings, android_strings)
    attr_accessor :type

    # @return [Array<String>] Tag filters (optional)
    attr_accessor :tags

    # @return [Array<String>] Filters by 'translated', 'untranslated', 'fuzzy', 'not_fuzzy', 'automatic', 'not_automatic', 'proofread', 'not_proofread' (optional)
    attr_accessor :filters

    # @return [Array<String>] The languages codes
    attr_accessor :languages

    # @return [Hash{Sting => String}] The languages aliases
    attr_accessor :language_alias

    # @return [String] The path template
    attr_accessor :path

    # @return [Hash{Sting => String}] The path replacements
    attr_accessor :path_replace

    # @return [Hash{Sting => String}] The path copies
    attr_accessor :path_copy

    def initialize(api_key:, project_id:, type:, tags:nil,
                   filters:nil, languages:, language_alias:nil,
                   path:, path_replace:nil, path_copy:nil)
      @api_key = from_env(api_key)
      @project_id = from_env(project_id.to_s)
      @type = type
      @tags = tags || []
      @filters = filters || []

      @languages = languages
      @language_alias = language_alias || {}

      @path = path
      @path_replace = path_replace || {}
      @path_copy = path_copy || {}
      if @path_replace.any? and @path_copy.any?
        @path_replace.each { |language_key, v|
          if @path_copy.key?(language_key)
            raise POEditor::Exception.new "'path_replace' and 'path_copy' are different strategies of one functionality and thus cannot be in use simultaneously for same language."
          end
        }
      end
    end

    def from_env(value)
      if value.start_with?("$")
        key = value[1..-1]
        ENV[key]
      else
        value
      end
    end
  end
end
